# Depman, version 2.1.0

Micro, single-file general-purpose version manager

## Repository

Upstream repository is <https://gitlab.com/xgqt/xgqt-python-app-depman/>.

## Package

Download from PYPI: <https://pypi.org/project/depman-app/>.

## License

### Code

Code in this project is licensed under the MPL, version 2.0.

    This Source Code Form is subject to the terms of the Mozilla Public
    License, v. 2.0. If a copy of the MPL was not distributed with this
    file, You can obtain one at http://mozilla.org/MPL/2.0/.
